@@ -8,10 +8,9 @@ struct TestEvent(String);
 // Mark the struct as a system event message.
 impl SystemEvent for TestEvent {}
 
-// The actor struct must derive Clone.
-#[derive(Clone)]
+// Define the actor
 struct TestActor {
-    counter: usize
+    counter: usize,
 }
 
 // Mark the struct as an actor.
@@ -42,7 +41,8 @@ impl Handler<TestEvent, TestMessage> for TestActor {
         self.counter += 1;
         log::debug!("counter is now {}", &self.counter);
         log::debug!("actor on system {}", ctx.system.name());
-        ctx.system.publish(TestEvent(format!("message received by '{}'", ctx.path)));
+        ctx.system
+            .publish(TestEvent(format!("message received by '{}'", ctx.path)));
         "Ping!".to_string()
     }
 }
@@ -64,7 +64,7 @@ async fn simple_message() {
     // Create the actor system with the event bus
     let system = ActorSystem::new("test", bus);
     // Launch the actor on the actor system
-    let mut actor_ref = system.create_actor("test-actor", actor).await.unwrap();
+    let actor_ref = system.create_actor("test-actor", actor).await.unwrap();
 
     // Listen for events on the system event bus
     let mut events: EventReceiver<TestEvent> = system.events();
@@ -72,7 +72,7 @@ async fn simple_message() {
         loop {
             match events.recv().await {
                 Ok(event) => println!("Received event! {:?}", event),
-                Err(err) => println!("Error receivng event!!! {:?}", err)
+                Err(err) => println!("Error receivng event!!! {:?}", err),
             }
         }
     });
@@ -84,4 +84,4 @@ async fn simple_message() {
     let response = actor_ref.ask(msg).await.unwrap();
 
     assert_eq!(response, "Ping!".to_string());
-}
\ No newline at end of file
+}
