@@ -7,19 +7,21 @@ struct TestEvent(String);
 impl SystemEvent for TestEvent {}
 
 // Define the actor
-#[derive(Clone)]
 struct TestActor {
-    counter: usize
+    counter: usize,
 }
 
 #[async_trait]
 impl Actor<TestEvent> for TestActor {
-    async fn pre_start(&mut self, ctx: &mut ActorContext<TestEvent>) {
-        ctx.system.publish(TestEvent(format!("Actor '{}' started.", ctx.path)));
+    async fn pre_start(&mut self, ctx: &mut ActorContext<TestEvent>) -> Result<(), ActorError> {
+        ctx.system
+            .publish(TestEvent(format!("Actor '{}' started.", ctx.path)));
+        Ok(())
     }
 
     async fn post_stop(&mut self, ctx: &mut ActorContext<TestEvent>) {
-        ctx.system.publish(TestEvent(format!("Actor '{}' stopped.", ctx.path)));
+        ctx.system
+            .publish(TestEvent(format!("Actor '{}' stopped.", ctx.path)));
     }
 }
 
@@ -35,14 +37,17 @@ impl Message for TestMessage {
 #[async_trait]
 impl Handler<TestEvent, TestMessage> for TestActor {
     async fn handle(&mut self, msg: TestMessage, ctx: &mut ActorContext<TestEvent>) -> String {
-        ctx.system.publish(TestEvent(format!("Message {:?} received by '{}'", &msg, ctx.path)));
+        ctx.system.publish(TestEvent(format!(
+            "Message {:?} received by '{}'",
+            &msg, ctx.path
+        )));
         self.counter += 1;
         "Ping!".to_string()
     }
 }
 
 // Define another message type the actor will handle
-#[derive(Clone, Debug)]
+#[derive(Default, Clone, Debug)]
 struct OtherMessage(usize);
 
 impl Message for OtherMessage {
@@ -53,7 +58,10 @@ impl Message for OtherMessage {
 #[async_trait]
 impl Handler<TestEvent, OtherMessage> for TestActor {
     async fn handle(&mut self, msg: OtherMessage, ctx: &mut ActorContext<TestEvent>) -> usize {
-        ctx.system.publish(TestEvent(format!("Message {:?} received by '{}'", &msg, ctx.path)));
+        ctx.system.publish(TestEvent(format!(
+            "Message {:?} received by '{}'",
+            &msg, ctx.path
+        )));
         self.counter += msg.0;
         self.counter
     }
@@ -70,14 +78,14 @@ async fn multi_message() {
 
     let bus = EventBus::<TestEvent>::new(1000);
     let system = ActorSystem::new("test", bus);
-    let mut actor_ref = system.create_actor("test-actor", actor).await.unwrap();
+    let actor_ref = system.create_actor("test-actor", actor).await.unwrap();
 
     let mut events = system.events();
     tokio::spawn(async move {
         loop {
             match events.recv().await {
                 Ok(event) => println!("Received event! {:?}", event),
-                Err(err) => println!("Error receivng event!!! {:?}", err)
+                Err(err) => println!("Error receivng event!!! {:?}", err),
             }
         }
     });
@@ -91,4 +99,4 @@ async fn multi_message() {
     let msg_b = OtherMessage(10);
     let response_b = actor_ref.ask(msg_b).await.unwrap();
     assert_eq!(response_b, 11);
-}
\ No newline at end of file
+}
